@@ -6,8 +6,7 @@
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef TESTKODAYMATRIX_H
-#define TESTKODAYMATRIX_H
+#pragma once
 
 #include <QObject>
 
@@ -17,5 +16,3 @@ class KODayMatrixTest : public QObject
 private Q_SLOTS:
     void testMatrixLimits();
 };
-
-#endif
