@@ -391,7 +391,7 @@ const QDate &KODayMatrix::getDate(int offset) const
 QString KODayMatrix::getHolidayLabel(int offset) const
 {
     if (offset < 0 || offset > NUMDAYS - 1) {
-        return QString();
+        return {};
     }
     return mHolidays[offset];
 }
