@@ -11,8 +11,9 @@
 #include "korganizerinterface.h"
 #include "todoplugin.h"
 #include <CalendarSupport/CalendarSingleton>
-#include <CalendarSupport/Utils>
+#include <kcalendarcore_version.h>
 
+#include <Akonadi/CalendarUtils>
 #include <Akonadi/Collection>
 #include <Akonadi/IncidenceChanger>
 #include <Akonadi/ItemFetchScope>
@@ -125,9 +126,18 @@ void TodoSummaryWidget::updateView()
         prList.append(todo);
     }
     if (!prList.isEmpty()) {
+#if KCALENDARCORE_VERSION < QT_VERSION_CHECK(5, 95, 0)
         prList = Akonadi::ETMCalendar::sortTodos(prList, KCalendarCore::TodoSortSummary, KCalendarCore::SortDirectionAscending);
         prList = Akonadi::ETMCalendar::sortTodos(prList, KCalendarCore::TodoSortPriority, KCalendarCore::SortDirectionAscending);
         prList = Akonadi::ETMCalendar::sortTodos(prList, KCalendarCore::TodoSortDueDate, KCalendarCore::SortDirectionAscending);
+#else
+        KCalendarCore::Todo::List todoListSorted1(prList);
+        KCalendarCore::Todo::List todoListSorted2(prList);
+        KCalendarCore::Todo::List todoListSorted3(prList);
+        prList = Akonadi::ETMCalendar::sortTodos(std::move(todoListSorted1), KCalendarCore::TodoSortSummary, KCalendarCore::SortDirectionAscending);
+        prList = Akonadi::ETMCalendar::sortTodos(std::move(todoListSorted2), KCalendarCore::TodoSortPriority, KCalendarCore::SortDirectionAscending);
+        prList = Akonadi::ETMCalendar::sortTodos(std::move(todoListSorted3), KCalendarCore::TodoSortDueDate, KCalendarCore::SortDirectionAscending);
+#endif
     }
 
     // The to-do print consists of the following fields:
@@ -294,7 +304,7 @@ void TodoSummaryWidget::viewTodo(const QString &uid)
 
 void TodoSummaryWidget::removeTodo(const Akonadi::Item &item)
 {
-    (void) mChanger->deleteIncidence(item);
+    (void)mChanger->deleteIncidence(item);
 }
 
 void TodoSummaryWidget::completeTodo(Akonadi::Item::Id id)
@@ -302,11 +312,11 @@ void TodoSummaryWidget::completeTodo(Akonadi::Item::Id id)
     Akonadi::Item todoItem = mCalendar->item(id);
 
     if (todoItem.isValid()) {
-        KCalendarCore::Todo::Ptr todo = CalendarSupport::todo(todoItem);
+        KCalendarCore::Todo::Ptr todo = Akonadi::CalendarUtils::todo(todoItem);
         if (!todo->isReadOnly()) {
             KCalendarCore::Todo::Ptr oldTodo(todo->clone());
             todo->setCompleted(QDateTime::currentDateTime());
-            (void) mChanger->modifyIncidence(todoItem, oldTodo);
+            (void)mChanger->modifyIncidence(todoItem, oldTodo);
         }
     }
 }
@@ -320,18 +330,17 @@ void TodoSummaryWidget::popupMenu(const QString &uid)
     Akonadi::Item item = mCalendar->item(uid);
     QMenu popup(this);
     QAction *editIt = popup.addAction(i18n("&Edit To-do..."));
+    editIt->setIcon(QIcon::fromTheme(QStringLiteral("document-edit")));
     QAction *delIt = popup.addAction(i18n("&Delete To-do"));
     delIt->setIcon(QIcon::fromTheme(QStringLiteral("edit-delete")));
-
-    QAction *doneIt = nullptr;
     delIt->setEnabled(mCalendar->hasRight(item, Akonadi::Collection::CanDeleteItem));
 
+    QAction *doneIt = nullptr;
     if (!todo->isCompleted()) {
         doneIt = popup.addAction(i18n("&Mark To-do Completed"));
         doneIt->setIcon(QIcon::fromTheme(QStringLiteral("task-complete")));
         doneIt->setEnabled(mCalendar->hasRight(item, Akonadi::Collection::CanChangeItem));
     }
-    // TODO: add icons to the menu actions
 
     const QAction *selectedAction = popup.exec(QCursor::pos());
     if (selectedAction == editIt) {
