@@ -13,13 +13,12 @@
 #include "calendarview.h"
 #include "impl/korganizerifaceimpl.h"
 #include "kocore.h"
-#include <CalendarSupport/Utils>
 
+#include <Akonadi/CalendarUtils>
 #include <KCalUtils/IncidenceFormatter>
 
 #include "korganizer_debug.h"
-#include <kcoreaddons_version.h>
-#if KCOREADDONS_VERSION < QT_VERSION_CHECK(6, 0, 0)
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include "korgmigrateapplication.h"
 #endif
 #include <KParts/StatusBarExtension>
@@ -32,7 +31,7 @@ K_PLUGIN_FACTORY(KOrganizerFactory, registerPlugin<KOrganizerPart>();)
 KOrganizerPart::KOrganizerPart(QWidget *parentWidget, QObject *parent, const QVariantList &)
     : KParts::ReadOnlyPart(parent)
 {
-#if KCOREADDONS_VERSION < QT_VERSION_CHECK(6, 0, 0)
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     KOrgMigrateApplication migrate;
     migrate.migrate();
 #endif
@@ -88,7 +87,7 @@ KOrganizerPart::~KOrganizerPart()
 void KOrganizerPart::slotChangeInfo(const Akonadi::Item &item, const QDate &date)
 {
     Q_UNUSED(date)
-    const KCalendarCore::Incidence::Ptr incidence = CalendarSupport::incidence(item);
+    const KCalendarCore::Incidence::Ptr incidence = Akonadi::CalendarUtils::incidence(item);
     if (incidence) {
         Q_EMIT textChanged(incidence->summary() + QLatin1String(" / ")
                            + KCalUtils::IncidenceFormatter::timeToString(incidence->dtStart().toLocalTime().time()));
