@@ -10,13 +10,13 @@
 #include "koglobals.h"
 #include "koprefs.h"
 #include <CalendarSupport/KCalPrefs>
-#include <KCheckComboBox>
 #include <KComboBox>
 #include <KHolidays/HolidayRegion>
 #include <KLocalizedString>
 #include <KPluginFactory>
 #include <KTimeComboBox>
 #include <KUrlRequester>
+#include <Libkdepim/KCheckComboBox>
 #include <QCheckBox>
 #include <QComboBox>
 #include <QFrame>
@@ -86,7 +86,7 @@ KOPrefsDialogTime::KOPrefsDialogTime(QWidget *parent, const QVariantList &args)
         } else {
             label = i18nc("@item:inlistbox Holiday region, region language", "%1 (%2)", name, languageName);
         }
-        regionsMap.push_back(std::make_pair(label, regionCode));
+        regionsMap.emplace_back(label, regionCode);
     }
     std::sort(regionsMap.begin(), regionsMap.end(), [](const auto &lhs, const auto &rhs) {
         return lhs.first < rhs.first;
